# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.3] - 2024-04-02
- Moved to `ruff` and added tests

## [0.1.2] - 2024-03-07

- Added missing template example (assumes your Vue project has been built to `project/static/vue-frontend`)

## [0.1.1] - 2024-03-07

- Added test coverage

## [0.1.0] - 2022-04-19

- First release on PyPI.
